From d4eff65342d43c5b9087c263e726f060fd4a1995 Mon Sep 17 00:00:00 2001
From: Dominique Devriese <Dominique.Devriese@cs.kuleuven.be>
Date: Mon, 24 Sep 2012 11:09:16 +0200
Subject: [PATCH] fix compilation on GHC 7.4

---
 System/Directory.hs |   16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/System/Directory.hs b/System/Directory.hs
index 1e44248..9f50919 100644
--- a/System/Directory.hs
+++ b/System/Directory.hs
@@ -85,7 +85,7 @@ import System.FilePath
 import System.IO
 import System.IO.Error
 import Control.Monad           ( when, unless )
-import Control.Exception.Base
+import Control.Exception.Base as Exc
 
 #ifdef __NHC__
 import Directory -- hiding ( getDirectoryContents
@@ -392,7 +392,7 @@ createDirectoryIfMissing create_parents path0
 
     createDir :: FilePath -> (IOException -> IO ()) -> IO ()
     createDir dir notExistHandler = do
-      r <- try $ createDirectory dir
+      r <- Exc.try $ createDirectory dir
       case (r :: Either IOException ()) of
         Right ()                   -> return ()
         Left  e
@@ -416,7 +416,7 @@ createDirectoryIfMissing create_parents path0
                  then return ()
                  else throw e
 #endif
-              ) `catch` ((\_ -> return ()) :: IOException -> IO ())
+              ) `Exc.catch` ((\_ -> return ()) :: IOException -> IO ())
           | otherwise              -> throw e
 #endif  /* !__NHC__ */
 
@@ -482,7 +482,7 @@ removeDirectoryRecursive startLoc = do
   removeDirectory startLoc
   where
     rm :: FilePath -> IO ()
-    rm f = do temp <- try (removeFile f)
+    rm f = do temp <- Exc.try (removeFile f)
               case temp of
                 Left e  -> do isDir <- doesDirectoryExist f
                               -- If f is not a directory, re-throw the error
@@ -957,7 +957,7 @@ doesDirectoryExist name =
    (do stat <- Posix.getFileStatus name
        return (Posix.isDirectory stat))
 #endif
-   `catch` ((\ _ -> return False) :: IOException -> IO Bool)
+   `Exc.catch` ((\ _ -> return False) :: IOException -> IO Bool)
 
 {- |The operation 'doesFileExist' returns 'True'
 if the argument file exists and is not a directory, and 'False' otherwise.
@@ -971,7 +971,7 @@ doesFileExist name =
    (do stat <- Posix.getFileStatus name
        return (not (Posix.isDirectory stat)))
 #endif
-   `catch` ((\ _ -> return False) :: IOException -> IO Bool)
+   `Exc.catch` ((\ _ -> return False) :: IOException -> IO Bool)
 
 {- |The 'getModificationTime' operation returns the
 clock time at which the file or directory was last modified.
@@ -1071,11 +1071,11 @@ getHomeDirectory :: IO FilePath
 getHomeDirectory =
   modifyIOError ((`ioeSetLocation` "getHomeDirectory")) $ do
 #if defined(mingw32_HOST_OS)
-    r <- try $ Win32.sHGetFolderPath nullPtr Win32.cSIDL_PROFILE nullPtr 0
+    r <- Exc.try $ Win32.sHGetFolderPath nullPtr Win32.cSIDL_PROFILE nullPtr 0
     case (r :: Either IOException String) of
       Right s -> return s
       Left  _ -> do
-        r1 <- try $ Win32.sHGetFolderPath nullPtr Win32.cSIDL_WINDOWS nullPtr 0
+        r1 <- Exc.try $ Win32.sHGetFolderPath nullPtr Win32.cSIDL_WINDOWS nullPtr 0
         case r1 of
           Right s -> return s
           Left  e -> ioError (e :: IOException)
-- 
1.7.10.4

